@@ -25,8 +25,7 @@ print.summary.LORgee <- function(x, ...) {
   cat("\nLocal Odds Ratios Estimates:\n")
   print(round(x$local.odds.ratios$theta, 3))
   if (!is.null(x$pvalue)) {
-    cat("\npvalue of Null model:", ifelse(x$pvalue <= 1e-04, "<0.0001",
-      round(x$pvalue, 4)
-    ), "\n")
+    p_value <- format.pval(x$pvalue, eps = 0.0001, scientific = FALSE)
+    cat("\np-value of Null model:", p_value, "\n")
   }
 }
